@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0006';
+our $VERSION = '0.0007';
 
 use Moo;
 use strictures 2;
@@ -65,8 +65,8 @@ sub make_setting {
       $self->model,
       ['settings'],
       { id => $id },
-    )->expand(json => 'settings')->hash;
-    my $params = { %{ $result->{settings} }, %args };
+    )->expand(json => 'settings')->hash->{settings};
+    my $params = { %$result, %args };
     $self->_sqlite->update(
       $self->model,
       { settings => to_json($params) },
@@ -113,6 +113,15 @@ sub recall_settings {
   return \@settings;
 }
 
+
+sub recall_names {
+  my ($self) = @_;
+  my $results = $self->_sqlite->query(
+    'select distinct name from ' . $self->model
+  )->array;
+  return $results;
+}
+
 1;
 
 __END__
@@ -127,7 +136,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0006
+version 0.0007
 
 =head1 SYNOPSIS
 
@@ -144,7 +153,10 @@ version 0.0006
   # { etc => '...' }
 
   my $settings = $synth->recall_settings(name => $name);
-  # [ 1 => { etc => '...' }, 2 => { etc => '???' }, ]
+  # [ 1 => { etc => '...' }, 2 => { etc => '???' } ]
+
+  my $names = $synth->recall_names;
+  # [ 'Foo!' ]
 
 =head1 DESCRIPTION
 
@@ -221,8 +233,16 @@ Return the parameters of a setting for the given B<id>.
 
 Return all the settings for a given B<name>.
 
+=head2 recall_names
+
+  my $names = $synth->recall_names;
+
+Return all the setting names.
+
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file in this distribution
+
 L<Moo>
 
 L<Mojo::JSON>
